@@ -195,11 +195,11 @@ sub work_once {
     $self->call_hook('deserialize', $job);
     $self->call_hook('pre_work',    $job);
 
-    my $res = $worker_class->work_safely($job);
+    $worker_class->work_safely($job);
 
     $self->call_hook('post_work',   $job);
 
-    return $res;
+    return 1;
 }
 
 sub lookup_job {
